// lib/init.js
const { promisify } = require('util') // 将函数转为promise格式
const figlet = promisify(require('figlet')) // 字体包
const inquirer = require("inquirer")
const prompt = inquirer.createPromptModule();

const { repoMap } = require("./constants")
const spawn = require("./spawn")
const clear = require('clear') // 控制台清屏
const chalk = require('chalk') // 修改控制台中字符串的样式
const log = ctx => console.log(chalk.green(ctx)) // 封装日志输出
// 新增 clone 引入
const { clone } = require('./download')

module.exports = async (name, branch = "master") => {
	// 打印欢迎页面
	clear()
	const data = await figlet('Hello ' + name)
	log(data)
	prompt([
		{
			type: "list",
			name: "template",
			message: "请选择工程模板，idfe-craco是基于craco搭建的react项目，idfe-vite是基于vite搭建可兼容安卓5.x的模板",
			choices: ["idfe-craco", "idfe-vite"]
		},
		{
			type: "input",
			name: "branch",
			message: "输入要拉取的模板分支，默认为master",
		}
	]).then(async (result) => {
		
		log('🚀创建项目 ' + name)
		const template = repoMap[result.template]
		const branch = result.branch || "master"
		console.log("result", `direct:${template}`)
		await clone(`${template}`, name)
		// 安装依赖
		log('💣安装依赖......')
		await spawn('npm', ['install'], { cwd: `./${name}` })
		log(`
    👌安装完成
    To get start
    ======================
      cd ${name}
      npm start
    ======================
  `)
	}).catch(error => {
		console.log("error:", error)
	})
}